@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -320,9 +320,15 @@ gint i;
 	PREFS->appendscheduled = FALSE;
 	PREFS->do_update_currency = FALSE;
 
+	PREFS->bak_is_automatic = TRUE;
+	PREFS->bak_max_num_copies = 5;
+
 	PREFS->heritdate = FALSE;
 	PREFS->hidereconciled = FALSE;
 	PREFS->showremind = TRUE;
+	//#1673048
+	PREFS->txn_memoacp = TRUE;
+	PREFS->txn_memoacp_days = 365;
 
 	PREFS->toolbar_style = 4;	//text beside icons
 	PREFS->custom_colors = TRUE;
@@ -359,20 +365,22 @@ gint i;
 	PREFS->pnl_upc_col_pay_width = -1;
 	PREFS->pnl_upc_col_mem_width = -1;
 
+	i = 0;
+	PREFS->lst_impope_columns[i++] = LST_DSPOPE_DATE;	  //always displayed
+	PREFS->lst_impope_columns[i++] = LST_DSPOPE_MEMO;
+	PREFS->lst_impope_columns[i++] = LST_DSPOPE_AMOUNT;
+	PREFS->lst_impope_columns[i++] = LST_DSPOPE_INFO;
+	PREFS->lst_impope_columns[i++] = LST_DSPOPE_PAYEE;
+	PREFS->lst_impope_columns[i++] = LST_DSPOPE_CATEGORY;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_TAGS;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_CLR;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_STATUS;  //always displayed
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_EXPENSE;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_INCOME;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_BALANCE;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_ACCOUNT;
 
 	i = 0;
-	/* prior v4.5
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_STATUS;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_DATE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INFO;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_PAYEE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_WORDING;
-	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_AMOUNT;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_EXPENSE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INCOME;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_CATEGORY;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_TAGS;
-	*/
 	PREFS->lst_ope_columns[i++] = LST_DSPOPE_STATUS;  //always displayed
 	PREFS->lst_ope_columns[i++] = LST_DSPOPE_DATE;	  //always displayed
 	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INFO;
@@ -384,13 +392,14 @@ gint i;
 	PREFS->lst_ope_columns[i++] = LST_DSPOPE_EXPENSE;
 	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INCOME;
 	PREFS->lst_ope_columns[i++] = LST_DSPOPE_BALANCE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_WORDING;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_MEMO;
+	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_ACCOUNT;
 
 	PREFS->lst_ope_sort_id    = LST_DSPOPE_DATE;
 	PREFS->lst_ope_sort_order = GTK_SORT_ASCENDING;
 
 	for( i=0;i<NUM_LST_DSPOPE;i++)
-		PREFS->lst_ope_col_size[i] = -1;
+		PREFS->lst_ope_col_width[i] = -1;
 
 	//PREFS->base_cur.nbdecimal = 2;
 	//PREFS->base_cur.separator = TRUE;
@@ -402,6 +411,7 @@ gint i;
 
 	//import/export
 	PREFS->dtex_nointro = TRUE;
+	PREFS->dtex_ucfirst = FALSE;
 	//PREFS->dtex_datefmt
 	PREFS->dtex_ofxname = 1;
 	PREFS->dtex_ofxmemo = 2;
@@ -471,10 +481,12 @@ static void homebank_pref_get_boolean(
     const gchar *key,
 	gboolean *storage)
 {
+	DB( g_print(" search %s in %s\n", key, group_name) );
 
 	if( g_key_file_has_key(key_file, group_name, key, NULL) )
 	{
 		*storage = g_key_file_get_boolean(key_file, group_name, key, NULL);
+		DB( g_print(" stored boolean %d for %s at %x\n", *storage, key, *storage) );
 	}
 }
 
@@ -484,15 +496,12 @@ static void homebank_pref_get_integer(
     const gchar *key,
 	gint *storage)
 {
-
 	DB( g_print(" search %s in %s\n", key, group_name) );
 
-
 	if( g_key_file_has_key(key_file, group_name, key, NULL) )
 	{
 		*storage = g_key_file_get_integer(key_file, group_name, key, NULL);
-
-		DB( g_print(" store integer %d for %s at %x\n", *storage, key, *storage) );
+		DB( g_print(" stored integer %d for %s at %x\n", *storage, key, *storage) );
 	}
 }
 
@@ -502,10 +511,12 @@ static void homebank_pref_get_guint32(
     const gchar *key,
 	guint32 *storage)
 {
+	DB( g_print(" search %s in %s\n", key, group_name) );
 
 	if( g_key_file_has_key(key_file, group_name, key, NULL) )
 	{
 		*storage = g_key_file_get_integer(key_file, group_name, key, NULL);
+		DB( g_print(" stored guint32 %d for %s at %x\n", *storage, key, *storage) );
 	}
 }
 
@@ -515,10 +526,12 @@ static void homebank_pref_get_short(
     const gchar *key,
 	gshort *storage)
 {
+	DB( g_print(" search %s in %s\n", key, group_name) );
 
 	if( g_key_file_has_key(key_file, group_name, key, NULL) )
 	{
 		*storage = (gshort)g_key_file_get_integer(key_file, group_name, key, NULL);
+		DB( g_print(" stored short %d for %s at %x\n", *storage, key, *storage) );
 	}
 }
 
@@ -545,7 +558,9 @@ gchar *string;
 		string = g_key_file_get_string(key_file, group_name, key, NULL);
 		if( string != NULL )
 		{
-			*storage = g_strdup(string);
+			//*storage = g_strdup(string);
+			//leak
+			*storage = string;	//already a new allocated string
 
 			//DB( g_print(" store '%s' for %s at %x\n", string, key, *storage) );
 		}
@@ -674,9 +689,15 @@ GError *error = NULL;
 				homebank_pref_get_boolean(keyfile, group, "AppendScheduled", &PREFS->appendscheduled);
 				homebank_pref_get_boolean(keyfile, group, "UpdateCurrency", &PREFS->do_update_currency);	
 
+				homebank_pref_get_boolean(keyfile, group, "BakIsAutomatic", &PREFS->bak_is_automatic);
+				homebank_pref_get_short(keyfile, group, "BakMaxNumCopies", &PREFS->bak_max_num_copies);
+
 				homebank_pref_get_boolean(keyfile, group, "HeritDate", &PREFS->heritdate);
 				homebank_pref_get_boolean(keyfile, group, "HideReconciled", &PREFS->hidereconciled);
 				homebank_pref_get_boolean(keyfile, group, "ShowRemind", &PREFS->showremind);
+				homebank_pref_get_boolean(keyfile, group, "TxnMemoAcp", &PREFS->txn_memoacp);
+				homebank_pref_get_short(keyfile, group, "TxnMemoAcpDays", &PREFS->txn_memoacp_days);
+
 
 				if( g_key_file_has_key(keyfile, group, "ColumnsOpe", NULL) )
 				{
@@ -703,7 +724,7 @@ GError *error = NULL;
 
 						DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
 
-						if( length == NUM_LST_DSPOPE-1 )
+						if( length == NUM_LST_DSPOPE )
 						{
 							DB( g_print(" - copying column order from pref file\n") );
 							memcpy(PREFS->lst_ope_columns, src, length*sizeof(gint));
@@ -760,11 +781,15 @@ GError *error = NULL;
 
 					DB( g_print(" - length %d (max=%d)\n", length, NUM_LST_DSPOPE) );
 
-					if( length == NUM_LST_DSPOPE-1 )
+					if( length == NUM_LST_DSPOPE )
 					{
 						DB( g_print(" - copying column width from pref file\n") );
-						memcpy(PREFS->lst_ope_col_size, src, length*sizeof(gint));
+						memcpy(PREFS->lst_ope_col_width, src, length*sizeof(gint));
 					}
+
+					//leak
+					g_free(src);
+					
 				}
 			
 				homebank_pref_get_integer(keyfile, group, "OpeSortId", &PREFS->lst_ope_sort_id);
@@ -928,7 +953,8 @@ GError *error = NULL;
 
 				DB( g_print(" -> ** Exchange\n") );
 
-				//homebank_pref_get_boolean(keyfile, group, "DoIntro", &PREFS->dtex_nointro);
+				homebank_pref_get_boolean(keyfile, group, "DoIntro", &PREFS->dtex_nointro);
+				homebank_pref_get_boolean(keyfile, group, "UcFirst", &PREFS->dtex_ucfirst);
 				homebank_pref_get_integer(keyfile, group, "DateFmt", &PREFS->dtex_datefmt);
 				homebank_pref_get_integer(keyfile, group, "OfxName", &PREFS->dtex_ofxname);
 				homebank_pref_get_integer(keyfile, group, "OfxMemo", &PREFS->dtex_ofxmemo);
@@ -1003,6 +1029,8 @@ gsize length;
 		g_key_file_set_integer (keyfile, group, "BarStyle", PREFS->toolbar_style);
 		//g_key_file_set_integer (keyfile, group, "BarImageSize", PREFS->image_size);
 
+
+
 		g_key_file_set_boolean (keyfile, group, "CustomColors", PREFS->custom_colors);
 		g_key_file_set_string (keyfile, group, "ColorExp" , PREFS->color_exp);
 		g_key_file_set_string (keyfile, group, "ColorInc" , PREFS->color_inc);
@@ -1015,6 +1043,9 @@ gsize length;
 		homebank_pref_set_string  (keyfile, group, "ExportPath"   , PREFS->path_export);
 		//g_key_file_set_string  (keyfile, group, "NavigatorPath", PREFS->path_navigator);
 
+		g_key_file_set_boolean (keyfile, group, "BakIsAutomatic", PREFS->bak_is_automatic);
+		g_key_file_set_integer (keyfile, group, "BakMaxNumCopies", PREFS->bak_max_num_copies);
+
 		g_key_file_set_boolean (keyfile, group, "ShowSplash", PREFS->showsplash);
 		g_key_file_set_boolean (keyfile, group, "LoadLast", PREFS->loadlast);
 		g_key_file_set_boolean (keyfile, group, "AppendScheduled", PREFS->appendscheduled);
@@ -1023,9 +1054,11 @@ gsize length;
 		g_key_file_set_boolean (keyfile, group, "HeritDate", PREFS->heritdate);
 		g_key_file_set_boolean (keyfile, group, "HideReconciled", PREFS->hidereconciled);
 		g_key_file_set_boolean (keyfile, group, "ShowRemind", PREFS->showremind);
+		g_key_file_set_boolean (keyfile, group, "TxnMemoAcp", PREFS->txn_memoacp);
+		g_key_file_set_integer (keyfile, group, "TxnMemoAcpDays" , PREFS->txn_memoacp_days);
 
-		g_key_file_set_integer_list(keyfile, group, "ColumnsOpe", PREFS->lst_ope_columns, NUM_LST_DSPOPE-1);
-		g_key_file_set_integer_list(keyfile, group, "ColumnsOpeWidth", PREFS->lst_ope_col_size, NUM_LST_DSPOPE-1);
+		g_key_file_set_integer_list(keyfile, group, "ColumnsOpe", PREFS->lst_ope_columns, NUM_LST_DSPOPE);
+		g_key_file_set_integer_list(keyfile, group, "ColumnsOpeWidth", PREFS->lst_ope_col_width, NUM_LST_DSPOPE);
 		g_key_file_set_integer     (keyfile, group, "OpeSortId" , PREFS->lst_ope_sort_id);
 		g_key_file_set_integer     (keyfile, group, "OpeSortOrder" , PREFS->lst_ope_sort_order);
 
@@ -1114,7 +1147,8 @@ gsize length;
 
 
 		group = "Exchange";
-		//g_key_file_set_boolean (keyfile, group, "DoIntro", PREFS->dtex_nointro);
+		g_key_file_set_boolean (keyfile, group, "DoIntro", PREFS->dtex_nointro);
+		g_key_file_set_boolean (keyfile, group, "UcFirst", PREFS->dtex_ucfirst);
 		g_key_file_set_integer (keyfile, group, "DateFmt", PREFS->dtex_datefmt);
 		g_key_file_set_integer (keyfile, group, "OfxName", PREFS->dtex_ofxname);
 		g_key_file_set_integer (keyfile, group, "OfxMemo", PREFS->dtex_ofxmemo);
