@@ -258,10 +258,12 @@ GtkWidget *make_label(char *str, gfloat xalign, gfloat yalign)
 {
 GtkWidget *label = gtk_label_new_with_mnemonic (str);
 
-	//todo: deprecated in 3.14
+	#if GTK_MINOR_VERSION >= 16
+	gtk_label_set_xalign(GTK_LABEL(label), xalign);
+	gtk_label_set_yalign(GTK_LABEL(label), yalign);
+	#else
 	gtk_misc_set_alignment (GTK_MISC (label), xalign, yalign);
-	//gtk_label_set_xalign(GTK_LABEL(label), xalign);
-	//gtk_label_set_yalign(GTK_LABEL(label), yalign);
+	#endif
 	return label;
 }
 
@@ -280,16 +282,13 @@ GtkWidget *entry;
 }
 
 
-GtkWidget *make_search(GtkWidget *label)
+GtkWidget *make_search(void)
 {
 GtkWidget *search;
 
 	search = gtk_search_entry_new();
 	gtk_entry_set_placeholder_text(GTK_ENTRY(search), _("Search...") );
 
-	if(label)
-		gtk_label_set_mnemonic_widget (GTK_LABEL(label), search);
-
 	return search;
 }
 
@@ -412,7 +411,7 @@ const gchar *numtext;
 	//g_message("previous text='%s' dcpos:'%d'", numtext, dcpos);
 	for (i=0 ; i < length ; i++)
 	{
-		if( isdigit(text[i]) && ( (*position <= dcpos + digits) || dcpos < 0) )
+		if( g_ascii_isdigit(text[i]) && ( (*position <= dcpos + digits) || dcpos < 0) )
 			goto inserttext;
 
 		if( text[i]=='-' && *position==0 )	/* minus sign only at position 0 */
@@ -467,7 +466,7 @@ GtkWidget *spinner;
 GtkAdjustment *adj;
 
 	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 99999, 0.01, 1.0, 0.0);
-	spinner = gtk_spin_button_new (adj, 1.0, 6);
+	spinner = gtk_spin_button_new (adj, 1.0, 8);
 	//gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spinner), TRUE);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinner), TRUE);
 	g_object_set(spinner, "xalign", 1.0, NULL);
@@ -654,6 +653,25 @@ guint i;
 	return combobox;
 }
 
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+guint32 hb_combo_box_get_active_id(GtkComboBox *combobox)
+{
+const gchar* active_id = gtk_combo_box_get_active_id(combobox);
+	return atoi(active_id);
+}
+
+
+void hb_combo_box_set_active_id(GtkComboBox *combobox, guint32 active_id)
+{
+gchar idbuffer[12];
+
+	g_snprintf(idbuffer, 11, "%d", active_id);
+	gtk_combo_box_set_active_id(combobox, idbuffer);
+}
+
+
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 /*
